package cn.rankin.productservice.controller;

import cn.rankin.common.utils.api.model.APICodeManager;
import cn.rankin.common.utils.api.model.APIResult;
import cn.rankin.common.utils.dto.product.CourseDTO;
import cn.rankin.common.utils.dto.search.SearchDTO;
import cn.rankin.common.utils.api.page.Page;
import cn.rankin.productservice.entity.Course;
import cn.rankin.productservice.service.CourseService;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

@Slf4j
@RestController
@RequestMapping(value = "course")
public class CourseController {

    @Autowired
    private CourseService courseService;

    @RequestMapping(value = "/list", method = RequestMethod.GET)
    public APIResult<Page<Course>> getWareList(SearchDTO searchDTO) {
        Course course = new Course();

        String code = searchDTO.getCode();
        if (!StringUtils.isEmpty(code)) {
            course.setCode("%" + code + "%");
        }

        String name = searchDTO.getName();
        if (!StringUtils.isEmpty(name)) {
            course.setName("%" + name + "%");
        }

        return courseService.search(course, searchDTO.getPageNo(), searchDTO.getPageSize());
    }

    // 创建资源
    @RequestMapping(method = RequestMethod.POST)
    public APIResult<Course> create(@RequestBody CourseDTO courseDTO) {
        String code = courseDTO.getCode();
        if (StringUtils.isEmpty(code)) {
            return APIResult.error(APICodeManager.PARAMETER_ERROR);
        }

        if (courseService.exists(code)) {
            return APIResult.error(APICodeManager.ALREADY_EXISTS);
        }

        return courseService.create(courseDTO);
    }

    // 修改资源
    @RequestMapping(method = RequestMethod.PUT)
    public APIResult<Course> update(@RequestBody CourseDTO courseDTO) {
        if (courseDTO.getId() == null) {
            return APIResult.error(APICodeManager.PARAMETER_ERROR);
        }

        return courseService.update(courseDTO);
    }

    // 删除
    @RequestMapping(value = "/{id}", method = RequestMethod.DELETE)
    public APIResult<Boolean> delete(@PathVariable("id") String id) {
        if (StringUtils.isEmpty(id)) {
            return APIResult.error(APICodeManager.PARAMETER_ERROR);
        }

        return courseService.delete(id);
    }

    @RequestMapping(value = "/{id}", method = RequestMethod.GET)
    public APIResult<Course> getCourse(@PathVariable("id") String id) {
        if (StringUtils.isEmpty(id)) {
            return APIResult.error(APICodeManager.PARAMETER_ERROR);
        }

        return courseService.findById(id);
    }

}
