package cn.rankin.productservice.controller;

import cn.rankin.common.utils.api.model.APICodeManager;
import cn.rankin.common.utils.api.model.APIResult;
import cn.rankin.common.utils.api.page.Page;
import cn.rankin.common.utils.dto.product.ItemDTO;
import cn.rankin.common.utils.dto.search.ItemSearchDTO;
import cn.rankin.productservice.entity.Item;
import cn.rankin.productservice.service.ItemService;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

@RestController
@RequestMapping(value = "item")
public class ItemController {

    @Autowired
    private ItemService itemService;

    @RequestMapping(value = "/list", method = RequestMethod.GET)
    public APIResult<Page<Item>> search(ItemSearchDTO searchDTO) {
        Item item = new Item();

        String code = searchDTO.getCode();
        if (!StringUtils.isEmpty(code)) {
            item.setCode("%" + code + "%");
        }

        String name = searchDTO.getName();
        if (!StringUtils.isEmpty(name)) {
            item.setName("%" + name + "%");
        }

        // others
        item.setStatus(searchDTO.getStatus());
        item.setType(searchDTO.getType());
        item.setMerchantId(searchDTO.getMerchantId());

        return itemService.search(item, searchDTO.getPageNo(), searchDTO.getPageSize());
    }

    @RequestMapping(method = RequestMethod.POST)
    public APIResult<Item> create(@RequestBody ItemDTO itemDTO) {
        String code = itemDTO.getCode();
        if (StringUtils.isEmpty(code) || itemDTO.getMerchantId() == null) {
            return APIResult.error(APICodeManager.PARAMETER_ERROR);
        }
        // 保存商品信息
        return itemService.create(itemDTO);
    }

    @RequestMapping(method = RequestMethod.PUT)
    public APIResult<Item> update(@RequestBody ItemDTO itemDTO) {
        if (itemDTO.getId() == null) {
            return APIResult.error(APICodeManager.PARAMETER_ERROR);
        }

        return itemService.update(itemDTO);
    }

    @RequestMapping(value = "/{id}", method = RequestMethod.DELETE)
    public APIResult<Boolean> delete(@PathVariable("id") String itemId) {
        if (itemId == null) {
            return APIResult.error(APICodeManager.PARAMETER_ERROR);
        }

        return itemService.delete(itemId);
    }

}
