package cn.rankin.productservice.controller;

import cn.rankin.common.utils.api.model.APICodeManager;
import cn.rankin.common.utils.api.model.APIResult;
import cn.rankin.common.utils.dto.search.SearchDTO;
import cn.rankin.common.utils.api.page.Page;
import cn.rankin.common.utils.dto.product.LessonDTO;
import cn.rankin.productservice.entity.Lesson;
import cn.rankin.productservice.service.LessonService;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

@RestController
@RequestMapping(value = "lesson")
public class LessonController {

    @Autowired
    private LessonService lessonService;

    @RequestMapping(value = "/list", method = RequestMethod.GET)
    public APIResult<Page<Lesson>> getLessonList(SearchDTO searchDTO) {
        Lesson lesson = new Lesson();

        String code = searchDTO.getCode();
        if (!StringUtils.isEmpty(code)) {
            lesson.setCode("%" + code + "%");
        }

        String name = searchDTO.getName();
        if (!StringUtils.isEmpty(name)) {
            lesson.setName(name);
        }

        return lessonService.search(lesson, searchDTO.getPageNo(), searchDTO.getPageSize());
    }

    @RequestMapping(value = "/{id}", method = RequestMethod.GET)
    public APIResult<Lesson> getLesson(@PathVariable String id) {
        if (StringUtils.isEmpty(id)) {
            return APIResult.error(APICodeManager.PARAMETER_ERROR);
        }

        return lessonService.findById(id);
    }

    @RequestMapping(method = RequestMethod.POST)
    public APIResult<Lesson> create(@RequestBody LessonDTO lessonDTO) {
        String code = lessonDTO.getCode();
        if (lessonDTO.getId() != null || StringUtils.isEmpty(code)) {
            return APIResult.error(APICodeManager.PARAMETER_ERROR);
        }

        return lessonService.create(lessonDTO);
    }

    @RequestMapping(method = RequestMethod.PUT)
    public APIResult<Lesson> update(@RequestBody Lesson lesson) {
        if (lesson.getId() == null) {
            return APIResult.error(APICodeManager.PARAMETER_ERROR);
        }

        return lessonService.update(lesson);
    }

    @RequestMapping(value = "/{id}", method = RequestMethod.DELETE)
    public APIResult<Boolean> delete(@PathVariable("id") String id) {
        if (StringUtils.isEmpty(id)) {
            return APIResult.error(APICodeManager.PARAMETER_ERROR);
        }
        return lessonService.delete(id);
    }
}
