package cn.rankin.productservice.controller;

import cn.rankin.common.utils.api.model.APICodeManager;
import cn.rankin.common.utils.api.model.APIResult;
import cn.rankin.common.utils.api.page.Page;
import cn.rankin.common.utils.dto.search.SearchDTO;
import cn.rankin.common.utils.dto.product.SupportDTO;
import cn.rankin.productservice.entity.Support;
import cn.rankin.productservice.service.SupportService;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

@RestController
@RequestMapping(value = "support")
public class SupportController {

    @Autowired
    private SupportService supportService;

    @RequestMapping(value = "/list", method = RequestMethod.GET)
    public APIResult<Page<Support>> search(SearchDTO searchDTO) {
        Support support = new Support();

        String code = searchDTO.getCode();
        if (!StringUtils.isEmpty(code)) {
            support.setCode("%" + code + "%");
        }

        String name = searchDTO.getName();
        if (!StringUtils.isEmpty(name)) {
            support.setName("%" + name + "%");
        }

        return supportService.search(support, searchDTO.getPageNo(), searchDTO.getPageSize());
    }

    @RequestMapping(value = "/{id}", method = RequestMethod.GET)
    public APIResult<Support> getSupport(@PathVariable String id) {
        if (StringUtils.isEmpty(id)) {
            return APIResult.error(APICodeManager.PARAMETER_ERROR);
        }

        return supportService.findById(id);
    }

    @RequestMapping(method = RequestMethod.POST)
    public APIResult<Support> create(@RequestBody SupportDTO supportDTO) {
        String code = supportDTO.getCode();
        if (StringUtils.isEmpty(code)) {
            return APIResult.error(APICodeManager.PARAMETER_ERROR);
        }

        return supportService.create(supportDTO);
    }

    @RequestMapping(method = RequestMethod.PUT)
    public APIResult<Support> update(@RequestBody SupportDTO supportDTO) {
        if (supportDTO.getId() == null) {
            return APIResult.error(APICodeManager.PARAMETER_ERROR);
        }

        return supportService.update(supportDTO);
    }

    @RequestMapping(value = "/{id}", method = RequestMethod.DELETE)
    public APIResult<Boolean> delete(@PathVariable("id") String id) {
        if (StringUtils.isEmpty(id)) {
            return APIResult.error(APICodeManager.PARAMETER_ERROR);
        }

        return supportService.delete(id);
    }
}
