package cn.rankin.productservice.controller;

import cn.rankin.common.utils.api.model.APICodeManager;
import cn.rankin.common.utils.api.model.APIResult;
import cn.rankin.common.utils.api.page.Page;
import cn.rankin.common.utils.dto.product.TagDTO;
import cn.rankin.common.utils.dto.search.TagSearchDTO;
import cn.rankin.productservice.entity.Tag;
import cn.rankin.productservice.service.TagService;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

@Slf4j
@RestController
@RequestMapping(value = "tag")
public class TagController {

    @Autowired
    private TagService tagService;

    @RequestMapping(value = "/list", method = RequestMethod.GET)
    public APIResult<Page<Tag>> search(TagSearchDTO searchDTO) {
        Tag tag = new Tag();

        String code = searchDTO.getCode();
        if (!StringUtils.isEmpty(code)) {
            tag.setCode("%" + code + "%");
        }

        String name = searchDTO.getName();
        if (!StringUtils.isEmpty(name)) {
            tag.setName("%" + name + "%");
        }

        String merchantId = searchDTO.getMerchantId();
        if (merchantId != null) {
            tag.setMerchantId(merchantId);
        }

        return tagService.search(tag, searchDTO.getPageNo(), searchDTO.getPageSize());
    }

    @RequestMapping(method = RequestMethod.POST)
    public APIResult<Tag> create(@RequestBody TagDTO tagDTO) {
        String code = tagDTO.getCode();
        if (StringUtils.isEmpty(code)) {
            return APIResult.error(APICodeManager.PARAMETER_ERROR);
        }

        return tagService.create(tagDTO);
    }

    @RequestMapping(method = RequestMethod.PUT)
    public APIResult<Tag> update(@RequestBody TagDTO tagDTO) {
        if (tagDTO.getId() == null) {
            return APIResult.error(APICodeManager.PARAMETER_ERROR);
        }

        return tagService.update(tagDTO);
    }

    @RequestMapping(value = "/{code}", method = RequestMethod.DELETE)
    public APIResult<Boolean> delete(@PathVariable String code) {
        if (StringUtils.isEmpty(code)) {
            return APIResult.error(APICodeManager.PARAMETER_ERROR);
        }

        return tagService.delete(code);
    }
}
