package cn.rankin.productservice.entity;

import cn.rankin.common.utils.enums.BaseStatusEnum;
import cn.rankin.productservice.vo.CourseSubItemVo;
import com.fasterxml.jackson.annotation.JsonIgnore;
import lombok.Data;
import lombok.ToString;
import org.apache.commons.lang.StringUtils;
import org.hibernate.annotations.DynamicInsert;
import org.hibernate.annotations.DynamicUpdate;

import javax.persistence.*;
import java.io.Serializable;
import java.util.Date;
import java.util.List;

@Data
@ToString
@Entity
@Table(name = "lj_course")
@DynamicInsert
@DynamicUpdate
public class Course implements Serializable{

    @Id
    private String id;

    @Column(unique = true)
    private String code;

    @Column
    private String name;

    @Column
    private String title;

    @Column
    private String digest;

    @Column
    private String detail;

    @Column
    private String keyword;

    @Column(name = "cv_img_ids")
    private String cvImgIds;

    @Column(name = "bg_img_ids")
    private String bgImgIds;

    @Column
    @Enumerated(EnumType.ORDINAL)
    private BaseStatusEnum status;

    @Column(name = "gmt_created", updatable = false, insertable = false)
    @Temporal(TemporalType.TIMESTAMP)
    private Date gmtCreated;

    @Column(name = "gmt_modified")
    @Temporal(TemporalType.TIMESTAMP)
    private Date gmtModified;

    @JsonIgnore
    public boolean isRight() {
        if (StringUtils.isEmpty(code)) {
            return false;
        }
        return true;
    }

    @Transient
    private List<CourseSubItemVo> subItemList;

    @ManyToMany(fetch = FetchType.EAGER)
    @JoinTable(name = "lj_course_support_relation", joinColumns = {@JoinColumn(name = "course_id", referencedColumnName = "id")},
            inverseJoinColumns = {@JoinColumn(name = "support_id", referencedColumnName = "id")})
    private List<Support> supportList;
}
