package cn.rankin.productservice.entity;

import cn.rankin.common.utils.enums.ItemStatusEnum;
import cn.rankin.common.utils.enums.ItemTypeEnum;
import lombok.Data;
import lombok.ToString;
import org.hibernate.annotations.DynamicInsert;
import org.hibernate.annotations.DynamicUpdate;

import javax.persistence.*;
import java.io.Serializable;
import java.util.Date;
import java.util.List;
import java.util.Set;

@Data
@ToString
@Entity
@Table(name = "lj_item")
@DynamicInsert
@DynamicUpdate
public class Item implements Serializable {

    @Id
    private String id;

    @Column(name = "course_id")
    private String CourseId;

    @Column
    private String code;

    @Column
    private String name;

    @Column
    @Enumerated(EnumType.ORDINAL)
    private ItemTypeEnum type;

    @Column(name = "merchant_id")
    private String merchantId;

    @Column
    private Integer sort;

    @Enumerated(EnumType.ORDINAL)
    private ItemStatusEnum status;

    @Column(name = "gmt_created", updatable = false, insertable = false, columnDefinition = "timestamp NULL DEFAULT CURRENT_TIMESTAMP")
    @Temporal(TemporalType.TIMESTAMP)
    private Date gmtCreated;

    @Column(name = "gmt_modified", updatable = false, insertable = false, columnDefinition = "timestamp NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP")
    @Temporal(TemporalType.TIMESTAMP)
    private Date gmtModified;

    @OneToMany(cascade = CascadeType.ALL, fetch = FetchType.EAGER, mappedBy = "itemId")
    @OrderBy("duration asc")
    private Set<ItemPrice> priceList;

    @ManyToMany(fetch = FetchType.LAZY)
    @JoinTable(name = "lj_item_tag_relation", joinColumns = {@JoinColumn(name="item_id", referencedColumnName="id")},
            inverseJoinColumns = {@JoinColumn(name = "tag_id", referencedColumnName = "id", unique = false)})
    private Set<Tag> tagList;
}
