package cn.rankin.productservice.service;

import cn.rankin.common.utils.api.model.APICodeManager;
import cn.rankin.common.utils.api.model.APIResult;
import cn.rankin.common.utils.dto.product.ItemPriceDTO;
import cn.rankin.productservice.entity.ItemPrice;
import cn.rankin.productservice.repository.ItemPriceRepository;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.transaction.Transactional;
import java.util.ArrayList;
import java.util.List;

@Slf4j
@Service
public class ItemPriceService {

    @Autowired
    private ItemPriceRepository priceRepository;

    public List<ItemPrice> findByItemId(Long itemId) {
        return priceRepository.findByItemId(itemId);
    }

    public ItemPrice findById(String priceId) {
        return priceRepository.find(priceId);
    }

    public boolean exists(ItemPriceDTO priceDTO) {
        ItemPrice price = new ItemPrice();
        price.setItemId(priceDTO.getItemId());
        price.setType(priceDTO.getType());
        price.setDuration(priceDTO.getDuration());

        Long count = priceRepository.count(price);

        return count > 0L;
    }

    @Transactional
    public APIResult<ItemPrice> create(ItemPriceDTO priceDTO) {
        if (exists(priceDTO)) {
            return APIResult.error(APICodeManager.ALREADY_EXISTS);
        }

        ItemPrice price = new ItemPrice();
        BeanUtils.copyProperties(priceDTO, price);

        ItemPrice result = priceRepository.save(price);
        return APIResult.ok(result);
    }

    @Transactional
    public APIResult<ItemPrice> update(ItemPriceDTO priceDTO) {
        if (!exists(priceDTO)) {
            return APIResult.error(APICodeManager.NOT_EXISTS);
        }

        ItemPrice price = new ItemPrice();
        BeanUtils.copyProperties(priceDTO, price);
        ItemPrice result = priceRepository.update(price);

        return APIResult.ok(result);
    }

    @Transactional
    public APIResult<List<ItemPrice>> createMulti(List<ItemPriceDTO> priceDTOList) {
        List<ItemPrice> priceList = new ArrayList<>();
        priceDTOList.forEach( dto -> {
            ItemPrice price = new ItemPrice();
            BeanUtils.copyProperties(dto, price);
            priceList.add(price);
        });

        List<ItemPrice> result = priceRepository.save(priceList);

        return APIResult.ok(result);
    }

    @Transactional
    public APIResult<List<ItemPrice>> updateMulti(List<ItemPriceDTO> priceDTOList) {
        List<ItemPrice> priceList = new ArrayList<>();
        priceDTOList.forEach( dto -> {
            ItemPrice price = new ItemPrice();
            BeanUtils.copyProperties(dto, price);
            priceList.add(price);
        });

        List<ItemPrice> result = priceRepository.update(priceList);
        return APIResult.ok(result);
    }

    @Transactional
    public APIResult<Boolean> deleteById(String priceId) {
        Long count = priceRepository.countById(priceId);
        if (count == 0) {
            return APIResult.error(APICodeManager.NOT_EXISTS);
        }
        priceRepository.delete(priceId);
        return APIResult.ok(true);
    }
}
