package cn.rankin.productservice.service;

import cn.rankin.common.utils.api.model.APICodeManager;
import cn.rankin.common.utils.api.model.APIResult;
import cn.rankin.common.utils.api.page.Page;
import cn.rankin.common.utils.dto.product.LessonDTO;
import cn.rankin.productservice.entity.Lesson;
import cn.rankin.productservice.repository.LessonRepository;
import cn.rankin.productservice.repository.WareRepository;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.List;
import java.util.Set;

@Slf4j
@Service
public class LessonService {

    @Autowired
    private LessonRepository lessonRepository;

    @Autowired
    private WareRepository wareRepository;

    public APIResult<Page<Lesson>> search(Lesson lesson, Integer pageNo, Integer pageSize) {
        Long count = lessonRepository.count(lesson);
        Page<Lesson> page = new Page(count, pageNo, pageSize);

        if (count == 0) {
            return APIResult.ok(page);
        }

        List<Lesson> wareList = lessonRepository.find(lesson, page.getStart(), pageSize);
        page.setList(wareList);

        return APIResult.ok(page);
    }

    public static Lesson convert(LessonDTO lessonDTO) {
        Lesson lesson = new Lesson();
        BeanUtils.copyProperties(lessonDTO, lesson);

//        List<WareDTO> wareDTOList = lessonDTO.getWareList();
//        if (CollectionUtils.isEmpty(wareDTOList)) {
//            return lesson;
//        }
//
//        List<Ware> wareList = new ArrayList<>();
//        wareDTOList.forEach( dto -> {
//            Ware ware = new Ware();
//            BeanUtils.copyProperties(dto, ware);
//            wareList.add(ware);
//        });
//
//        lesson.setWareList(wareList);
        return lesson;
    }

    public APIResult<Lesson> findById(String id) {
        Lesson lesson = lessonRepository.find(id);
        if (lesson == null) {
            return APIResult.error(APICodeManager.NOT_EXISTS);
        }

        return APIResult.ok(lesson);
    }

    public boolean exists(String code) {
        Long count = lessonRepository.countByCode(code);
        return count > 0L;
    }

    public boolean checkWareIds(Set<String> wareIdSet) {
        if (wareIdSet == null || wareIdSet.size() == 0) {
            return true;
        }

        List<String> wareIdList = new ArrayList<>();
        wareIdList.addAll(wareIdSet);

        Long count = wareRepository.countByIdIn(wareIdList);
        if (count < wareIdSet.size()) {
            return false;
        }
        return true;
    }

    @Transactional
    public APIResult<Lesson> create(LessonDTO lessonDTO) {
        String code = lessonDTO.getCode();
        if (exists(code)) {
            return APIResult.error(APICodeManager.ALREADY_EXISTS);
        }

//        Set<String> wareIdSet = lessonDTO.getWareList();
//        if (!checkWareIds(wareIdSet)) {
//            log.error("lesson: {} contains error ware code: {}", code, JSON.toJSONString(wareIdSet));
//            return APIResult.error(APICodeManager.error("包含错误的课件"));
//        }

        Lesson lesson = convert(lessonDTO);
        Lesson result = lessonRepository.save(lesson);

//        String lessonId = result.getId();
//        updateWareRelation(lessonId, wareIdSet);

        return APIResult.ok(result);
    }

    @Transactional
    public APIResult<Lesson> update(Lesson lessonDTO) {
//        Set<String> wareIdSet = lessonDTO.getWareList();
//        if (!checkWareIds(wareIdSet)) {
//            return APIResult.error(APICodeManager.error("包含错误的课件"));
//        }

//        Lesson lesson = convert(lessonDTO);
        Lesson result = lessonRepository.update(lessonDTO);

//        String lessonId = result.getId();
//        updateWareRelation(lessonId, wareIdSet);

        return APIResult.ok(result);
    }

    @Transactional
    public APIResult<Boolean> delete(String id) {
        lessonRepository.delete(id);
        return APIResult.ok(true);
    }

}
