package cn.rankin.productservice.service;

import cn.rankin.common.utils.api.model.APICodeManager;
import cn.rankin.common.utils.api.model.APIResult;
import cn.rankin.common.utils.api.page.Page;
import cn.rankin.common.utils.dto.product.TagDTO;
import cn.rankin.common.utils.enums.BaseStatusEnum;
import cn.rankin.productservice.entity.Tag;
import cn.rankin.productservice.repository.TagRepository;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

@Slf4j
@Service
public class TagService {

    @Autowired
    private TagRepository tagRepository;

    public APIResult<Page<Tag>> search(Tag tag, Integer pageNo, Integer pageSize) {
        Long count = tagRepository.count(tag);
        Page<Tag> page = new Page(count, pageNo, pageSize);

        if (count == 0) {
            return APIResult.ok(page);
        }

        List<Tag> tagList = tagRepository.find(tag, page.getStart(), pageSize);
        page.setList(tagList);

        return APIResult.ok(page);
    }

    public boolean exists(String code) {
        Long count = tagRepository.countByCode(code);
        return count > 0L;
    }

    public static Tag convert(TagDTO tagDTO) {
        Tag tag = new Tag();
        BeanUtils.copyProperties(tagDTO, tag);
        return tag;
    }

    @Transactional
    public APIResult<Tag> create(TagDTO tagDTO) {
        String code = tagDTO.getCode();
        if (exists(code)) {
            return APIResult.error(APICodeManager.ALREADY_EXISTS);
        }

        Tag tag = convert(tagDTO);
        Tag result = tagRepository.save(tag);

        return APIResult.ok(result);
    }

    @Transactional
    public APIResult<Tag> update(TagDTO tagDTO) {
        String code = tagDTO.getCode();
        if (!exists(code)) {
            return APIResult.error(APICodeManager.NOT_EXISTS);
        }

        Tag tag = convert(tagDTO);
        Tag result = tagRepository.update(tag);

        return APIResult.ok(result);
    }

    @Transactional
    public APIResult<Boolean> delete(String id) {
        Integer count = tagRepository.updateStatusById(id, BaseStatusEnum.DEL);
        if (count > 0) {
            return APIResult.ok(true);
        }
        return APIResult.error(APICodeManager.NOT_EXISTS);
    }
}
