package cn.rankin.productservice.service;

import cn.rankin.common.utils.api.model.APICodeManager;
import cn.rankin.common.utils.api.model.APIResult;
import cn.rankin.common.utils.api.page.Page;
import cn.rankin.common.utils.dto.product.WareDTO;
import cn.rankin.productservice.entity.Ware;
import cn.rankin.productservice.repository.WareRepository;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

@Slf4j
@Service
public class WareService {

    @Autowired
    private WareRepository wareRepository;

    public APIResult<Page<Ware>> search(Ware ware, Integer pageNo, Integer pageSize) {
        Long count = wareRepository.count(ware);
        Page<Ware> page = new Page(count, pageNo, pageSize);

        if (count == 0) {
            return APIResult.ok(page);
        }

        List<Ware> wareList = wareRepository.find(ware, page.getStart(), pageSize);
        page.setList(wareList);

        return APIResult.ok(page);
    }

    public boolean exists(String code) {
        Long count = wareRepository.countByCode(code);
        return count > 0L;
    }

    public static Ware convert(WareDTO wareDTO) {
        Ware ware = new Ware();
        BeanUtils.copyProperties(wareDTO, ware);
        return ware;
    }

    @Transactional
    public APIResult<Ware> create(WareDTO wareDTO) {
        Ware ware = convert(wareDTO);
        Ware result = wareRepository.save(ware);
        return APIResult.ok(result);
    }

    @Transactional
    public APIResult<Ware> update(WareDTO wareDTO) {
        Ware ware = convert(wareDTO);
        Ware result = wareRepository.update(ware);

        return APIResult.ok(result);
    }

    @Transactional
    public APIResult<Boolean> delete(String id) {
        wareRepository.delete(id);
        return APIResult.ok(true);
    }

    public APIResult<Ware> findById(String id) {
        Ware ware = wareRepository.find(id);
        if (ware == null) {
            return APIResult.error(APICodeManager.NOT_EXISTS);
        }
        return APIResult.ok(ware);
    }

}
