package cn.rankin.productservice.utils;

import cn.rankin.common.utils.dto.product.*;
import cn.rankin.productservice.entity.*;
import org.springframework.beans.BeanUtils;

import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

public class DTOConverter {

    // ItemDTO to Item
    public static Item convert(ItemDTO itemDTO) {
        Item item = new Item();
        BeanUtils.copyProperties(itemDTO, item);

        List<ItemPriceDTO> priceDTOList = itemDTO.getPriceList();
        if (priceDTOList == null || priceDTOList.size() == 0) {
            return item;
        }

        Set<ItemPrice> priceList = new HashSet<>();
        priceDTOList.forEach(dto -> priceList.add(convert(dto)));
        item.setPriceList(priceList);

        Set<String> tagDTOList = itemDTO.getTagList();
        if (tagDTOList == null || tagDTOList.size() == 0) {
            return item;
        }
        Set<Tag> tagSet = new HashSet<>();
        tagDTOList.forEach( tagId -> {
            Tag tag = new Tag();
            tag.setId(tagId);
            tagSet.add(tag);
        });
        item.setTagList(tagSet);

        return item;
    }

    // CourseDTO to Course
    public static Course convert(CourseDTO courseDTO) {
        Course course = new Course();
        BeanUtils.copyProperties(courseDTO, course);

        List<SupportDTO> supportDTOList = courseDTO.getSupportList();
        if (supportDTOList == null || supportDTOList.size() == 0) {
            return course;
        }

        List<Support> supportList = new ArrayList<>();
        supportDTOList.forEach( dto -> supportList.add(convert(dto)));
        course.setSupportList(supportList);
        return course;
    }

    // WareDTO to Ware
    public static Ware convert(WareDTO wareDTO) {
        Ware ware = new Ware();
        BeanUtils.copyProperties(wareDTO, ware);
        return ware;
    }

    // SupportDTO to Support
    public static Support convert(SupportDTO supportDTO) {
        Support support = new Support();
        BeanUtils.copyProperties(supportDTO, support);
        return support;
    }

    // PriceDTO to Price
    public static ItemPrice convert(ItemPriceDTO itemPriceDTO) {
        ItemPrice itemPrice = new ItemPrice();
        BeanUtils.copyProperties(itemPriceDTO, itemPrice);
        return itemPrice;
    }
}
