package cn.rankin.resourceservice.controller;

import cn.rankin.common.utils.api.model.APICodeManager;
import cn.rankin.common.utils.api.model.APIResult;
import cn.rankin.common.utils.api.page.Page;
import cn.rankin.common.utils.dto.product.SearchDTO;
import cn.rankin.resourceservice.entity.Resource;
import cn.rankin.resourceservice.entity.ResourceType;
import cn.rankin.resourceservice.service.ResourceService;
import com.alibaba.fastjson.JSON;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

@Slf4j
@RestController
@RequestMapping(value = "resource")
public class ResourceController {

    @Autowired
    private ResourceService resourceService;

    @RequestMapping(value = "/list")
    public APIResult<Page<Resource>> search(SearchDTO searchDTO) {
        log.info(JSON.toJSONString(searchDTO));

        // 参数错误返回
        if (searchDTO == null || searchDTO.getType() == null) {
            return APIResult.error(APICodeManager.PARAMETER_ERROR);
        }

        Integer type = searchDTO.getType();
        if (type.intValue() == ResourceType.IMG) {
            // 图片本地取
            Resource resource = new Resource();

            String code = searchDTO.getCode();
            if (!StringUtils.isEmpty(code)) {
                resource.setCode("%" + code.trim() + "%");
            }

            String name = searchDTO.getName();
            if (!StringUtils.isEmpty(name)) {
                resource.setCode("%" + name.trim() + "%");
            }
            return resourceService.search(resource, searchDTO.getPageNo(), searchDTO.getPageSize());
        }else {
            // 其他去云平台
            if (searchDTO.getCode() != null) {
                return resourceService.findRemoteByCode(searchDTO.getCode());
            }else {
                return resourceService.findRemotePage(searchDTO);
            }
        }
    }

    @RequestMapping(method = RequestMethod.POST)
    public APIResult<Resource> create(@RequestBody Resource resource) {
        if (!resource.isRight() || resource.getId() != null) {
            return APIResult.error(APICodeManager.PARAMETER_ERROR);
        }

        if (resourceService.exists(resource.getCode())) {
            return APIResult.error(APICodeManager.ALREADY_EXISTS);
        }

        Resource result = resourceService.save(resource);

        return APIResult.ok(result);
    }
}
